maposm: Package description

maposmR Documentation

Package description

Description

The OpenStreetMap database provides a wide range of highly detailed geographic layers on a global scale. To obtain synthetic information for cartographic purposes, layers must be selected, simplified, merged, or modified. maposm downloads OpenStreetMap extracts and performs these operations to create a set of composite layers of urban areas, buildings, green spaces, main roads, secondary roads, railways, and water bodies.

om_get is used to download, merge and simplify the geographic layers.
om_map is used to map the layers. Several themes are available to map the layers ("light", "dark", "grey" and "pizza").
om_write can be used to write the layers to a geopackage file.
om_read can be used to read these geopackages.

Author(s)

Maintainer: Timothée Giraud timothee.giraud@cnrs.fr (ORCID)

Authors:

Other contributors:

  • Matthieu Viry (ORCID) [contributor]

  • Louis Laurian (ORCID) [contributor]

See Also

Useful links:


maposm documentation built on Sept. 17, 2026, 5:08 p.m.