| maposm | R Documentation |
The OpenStreetMap database provides a wide range of highly
detailed geographic layers on a global scale. To obtain synthetic
information for cartographic purposes, layers must be selected, simplified,
merged, or modified. maposm downloads OpenStreetMap extracts and performs
these operations to create a set of composite layers of urban areas,
buildings, green spaces, main roads, secondary roads, railways, and water
bodies.
om_get is used to download, merge and simplify the geographic layers.
om_map is used to map the layers. Several themes are available to map
the layers ("light", "dark", "grey" and "pizza").
om_write can be used to write the layers to a geopackage file.
om_read can be used to read these geopackages.
Maintainer: Timothée Giraud timothee.giraud@cnrs.fr (ORCID)
Authors:
Timothée Giraud timothee.giraud@cnrs.fr (ORCID)
Other contributors:
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.